@@ -226,7 +226,7 @@ for entry_point_name, name, cls, applicable_features_function in [
                 field(
                     "Directory where state should be saved",
                     default=pathlib.Path(
-                        "~", ".cache", "dffml", f"scikit-{entry_point_name}",
+                        "~", ".cache", "dffml", f"scikit-{entry_point_name}"
                     ),
                 ),
             ),
